@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::MetaProvides::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::MetaProvides::VERSION = '1.13000001';
+  $Dist::Zilla::Plugin::MetaProvides::VERSION = '1.14000000';
 }
 
 # ABSTRACT: Generating and Populating 'provides' in your META.yml
@@ -23,7 +23,7 @@ Dist::Zilla::Plugin::MetaProvides - Generating and Populating 'provides' in your
 
 =head1 VERSION
 
-version 1.13000001
+version 1.14000000
 
 =head1 SYNOPSIS
 
@@ -33,13 +33,11 @@ In your projects dist.ini
     inherit_version = 0    ;optional flag
     inherit_missing = 0    ;optional flag
     meta_noindex    = 1    ;optional flag
-    skip_underscore = 1    ;optional flag
 
     [MetaProvides::Package]
     inherit_version = 0    ;optional flag
     inherit_missing = 0    ;optional flag
     meta_noindex    = 1    ;optional flag
-    skip_underscore = 1    ;optional flag
 
     [MetaProvides::FromFile]
     inherit_version = 0     ;optional flag
@@ -47,7 +45,6 @@ In your projects dist.ini
     file = some_file.ini    ;mandatory flag
     reader_name = Config::INI::Reader ;optional flag
     meta_noindex    = 1     ;optional and useless flag
-    skip_underscore = 1     ;its there as an option, but its probably stupid.
 
 And then in some_file.ini
 
@@ -163,30 +160,6 @@ to not be provided in the metadata.
 
 L<Dist::Zilla::Role::MetaProvider::Provider/meta_noindex>
 
-=head2 skip_underscore
-
-Filter out detected namespaces with a token with a leading C<_>, ie:
-
-    Foo::Bar::_internal::Baz;
-
-This is a convenience to provide sane defaults. For more controlled exclusion of namespaces, see L<Dist::Zilla::Plugin::MetaNoIndex>
-
-=head3 values
-
-=over 4
-
-=item * C<< '0' >>
-
-I<underscore>'d namespaces will be included.
-
-=item * C<< '1' >> B<[default]>
-
-I<underscore>'d namespaces will not be included.
-
-=back
-
-L<Dist::Zilla::Role::MetaProvider::Provider/skip_underscore>
-
 =head2 file
 
 ( L<Dist::Zilla::Plugin::MetaProvides::FromFile> )
